# RSIDBuildTranslator

RSIDBuildTranslator is a tool that annotates genetic data with rsIDs, chromosome, and position from GRCh37 or GRCh38, using whichever is available in your data. The database used in this tool is based on GTEx v10 whole genome sequencing variants from 953 individuals, and has a coverage of roughly 48.5M variants. 

This tool can be used on tabular data like for example, GWAS summary statistics. 